@@ -16,6 +16,7 @@ warnings.filterwarnings("ignore")
 
 
 def init_dataframe(args, input_file):
+    """Initialize dataframe with data from input file; convert current, temperature and pressure to SI units"""
     convert_current = 1000
     check_na = -999
 
@@ -40,6 +41,7 @@ def init_dataframe(args, input_file):
 
 
 def get_station(args, input_file, stations):
+    """Get latitude, longitude and name for each station"""
     path = 'resources/promice/aliases.txt'
     aliases = {}
     with open(common.relative_path(path)) as stream:
@@ -58,6 +60,7 @@ def get_station(args, input_file, stations):
 
 
 def get_time_and_sza(args, dataframe, longitude, latitude):
+    """Calculate additional time related variables"""
     dtime_1970, tz = common.time_common(args.tz)
 
     num_rows = dataframe['year'].size
@@ -72,6 +75,8 @@ def get_time_and_sza(args, dataframe, longitude, latitude):
         time[idx] = (dtime - dtime_1970).total_seconds()
         time_bounds[idx] = (time[idx], time[idx] + common.seconds_in_hour)
 
+        # Each timestamp is average of current and next hour values i.e. value at hour=5 is average of hour=5 and hour=6
+        # Our 'time' variable will represent values at half-hour i.e. 5.5 in above case, so add 30 minutes to all.
         time[idx] = time[idx] + common.seconds_in_half_hour
         dtime = datetime.utcfromtimestamp(time[idx])
         dates.append(int(dtime.date().strftime("%Y%m%d")))
@@ -86,6 +91,7 @@ def get_time_and_sza(args, dataframe, longitude, latitude):
 
 
 def get_ice_velocity(args, dataframe, delta_x, delta_y):
+    """Calculate GPS-derived ice velocity using Haversine formula"""
     num_rows = dataframe['year'].size
     R = 6373.0  # Approx radius of earth
     fillvalue = common.get_fillvalue(args)
@@ -125,6 +131,7 @@ def get_ice_velocity(args, dataframe, delta_x, delta_y):
 
 
 def fill_ice_velocity(args, dataframe, dataset):
+    """Calculate total ice velocity and its x, y components"""
     params = (
         ('ice_velocity_GPS_total', 1, 1),
         ('ice_velocity_GPS_x', 0, 1),
@@ -134,8 +141,9 @@ def fill_ice_velocity(args, dataframe, dataset):
 
 
 def convert_coordinates(args, dataframe):
-    # Exclude NAs
+    """Convert latitude_GPS and longitude_GPS units from ddmm to degrees"""
     fillvalue = common.get_fillvalue(args)
+    # Exclude NAs
     df1 = dataframe[dataframe.latitude_GPS != fillvalue]
     df2 = dataframe[dataframe.longitude_GPS != fillvalue]
 
@@ -150,6 +158,7 @@ def convert_coordinates(args, dataframe):
 
 
 def promice2nc(args, input_file, output_file, stations):
+    """Main function to convert PROMICE txt file to netCDF"""
     df, temperature_vars = init_dataframe(args, input_file)
     ds = xr.Dataset.from_dataframe(df)
     ds = ds.drop('time')
